# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 1.8.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from public_api_server_connector.models.transcription_language_code import TranscriptionLanguageCode  # noqa: E501

class TestTranscriptionLanguageCode(unittest.TestCase):
    """TranscriptionLanguageCode unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testTranscriptionLanguageCode(self):
        """Test TranscriptionLanguageCode"""
        # inst = TranscriptionLanguageCode()

if __name__ == '__main__':
    unittest.main()
